Plugin API
**********

Balder provides a separate class that helps to implement your own plugin.

The ``BalderPlugin``
====================

The main object to get access to the deep functionality of Balder is the :class:`BalderPlugin` class. You can
overwrite it in every `balderglob.py` file.

.. autoclass:: balder.BalderPlugin
    :members:
